==> jc-1.4.0.tar.gz: java/nio/channels/VMChannels.h <==
// final class java.nio.channels.VMChannels

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bdc323aba17fedb4 java_nio_channels_VMChannels

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_VMChannels_H_
#define _JC_java_nio_channels_VMChannels_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_channels_Channel$object;
struct _jc_java_nio_channels_ReadableByteChannel$object;
struct _jc_java_nio_channels_WritableByteChannel$object;

// Typedefs
typedef struct _jc_java_nio_channels_VMChannels$sub_refs	_jc_java_nio_channels_VMChannels$sub_refs;
typedef struct _jc_java_nio_channels_VMChannels$sub_nonrefs	_jc_java_nio_channels_VMChannels$sub_nonrefs;
typedef struct _jc_java_nio_channels_VMChannels$refs	_jc_java_nio_channels_VMChannels$refs;
typedef struct _jc_java_nio_channels_VMChannels$nonrefs	_jc_java_nio_channels_VMChannels$nonrefs;
typedef struct _jc_java_nio_channels_VMChannels$object	_jc_java_nio_channels_VMChannels$object;

typedef struct _jc_java_nio_channels_VMChannels$fields_struct	_jc_java_nio_channels_VMChannels$fields_struct;
typedef const struct _jc_java_nio_channels_VMChannels$vmethods	_jc_java_nio_channels_VMChannels$vmethods;
typedef const struct _jc_java_nio_channels_VMChannels$vtable	_jc_java_nio_channels_VMChannels$vtable;
typedef const struct _jc_java_nio_channels_VMChannels$vtype	_jc_java_nio_channels_VMChannels$vtype;

// Class fields structure
struct _jc_java_nio_channels_VMChannels$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24nio__24channels__24FileChannelImpl;
	struct _jc_java_lang_Class$object	*class__24java__24io__24FileInputStream;
	struct _jc_java_lang_Class$object	*class__24java__24io__24FileOutputStream;
};
extern _jc_java_nio_channels_VMChannels$fields_struct _jc_java_nio_channels_VMChannels$class_fields;

// Constructors
extern void _jc_java_nio_channels_VMChannels$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_VMChannels$object *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_nio_channels_VMChannels$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_java_lang_Object$object *_jc_java_nio_channels_VMChannels$method$createStream$33b6e9d8969afd40(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_object *);
extern struct _jc_java_io_InputStream$object *_jc_java_nio_channels_VMChannels$method$newInputStream$a1eabc144c1b09d2(_jc_env *, struct _jc_object *);
extern struct _jc_java_io_OutputStream$object *_jc_java_nio_channels_VMChannels$method$newOutputStream$eceb5d0d6e4ea2bb(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_java_nio_channels_VMChannels$vmethods {
};

// Vtable
struct _jc_java_nio_channels_VMChannels$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_VMChannels$vmethods	java_nio_channels_VMChannels;
};

// Vtype
struct _jc_java_nio_channels_VMChannels$vtype {
	_jc_type			type;
	_jc_java_nio_channels_VMChannels$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_VMChannels$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_VMChannels$refs {
    _jc_java_nio_channels_VMChannels$sub_refs	java_nio_channels_VMChannels;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_VMChannels$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_VMChannels$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_VMChannels$sub_nonrefs	java_nio_channels_VMChannels;
};

// Object instance structure
struct _jc_java_nio_channels_VMChannels$object {
	_jc_java_nio_channels_VMChannels$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_VMChannels$vtype	*vtype;
	_jc_java_nio_channels_VMChannels$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_VMChannels$vtype _jc_java_nio_channels_VMChannels$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_VMChannels, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_VMChannels$class_object;

#endif	/* _JC_java_nio_channels_VMChannels_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/VMChannels.h <==
// final class java.nio.channels.VMChannels

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bdc323aba17fedb4 java_nio_channels_VMChannels

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_VMChannels_H_
#define _JC_java_nio_channels_VMChannels_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_channels_Channel$object;
struct _jc_java_nio_channels_ReadableByteChannel$object;
struct _jc_java_nio_channels_WritableByteChannel$object;

// Typedefs
typedef struct _jc_java_nio_channels_VMChannels$sub_refs	_jc_java_nio_channels_VMChannels$sub_refs;
typedef struct _jc_java_nio_channels_VMChannels$sub_nonrefs	_jc_java_nio_channels_VMChannels$sub_nonrefs;
typedef struct _jc_java_nio_channels_VMChannels$refs	_jc_java_nio_channels_VMChannels$refs;
typedef struct _jc_java_nio_channels_VMChannels$nonrefs	_jc_java_nio_channels_VMChannels$nonrefs;
typedef struct _jc_java_nio_channels_VMChannels$object	_jc_java_nio_channels_VMChannels$object;

typedef struct _jc_java_nio_channels_VMChannels$fields_struct	_jc_java_nio_channels_VMChannels$fields_struct;
typedef const struct _jc_java_nio_channels_VMChannels$vmethods	_jc_java_nio_channels_VMChannels$vmethods;
typedef const struct _jc_java_nio_channels_VMChannels$vtable	_jc_java_nio_channels_VMChannels$vtable;
typedef const struct _jc_java_nio_channels_VMChannels$vtype	_jc_java_nio_channels_VMChannels$vtype;

// Class fields structure
struct _jc_java_nio_channels_VMChannels$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24nio__24channels__24FileChannelImpl;
	struct _jc_java_lang_Class$object	*class__24java__24io__24FileInputStream;
	struct _jc_java_lang_Class$object	*class__24java__24io__24FileOutputStream;
};
extern _jc_java_nio_channels_VMChannels$fields_struct _jc_java_nio_channels_VMChannels$class_fields;

// Constructors
extern void _jc_java_nio_channels_VMChannels$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_VMChannels$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_nio_channels_VMChannels$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_nio_channels_VMChannels$method$createStream$33b6e9d8969afd40(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_java_nio_channels_VMChannels$method$newInputStream$a1eabc144c1b09d2(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_OutputStream$object *_jc_java_nio_channels_VMChannels$method$newOutputStream$eceb5d0d6e4ea2bb(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_VMChannels$vmethods {
};

// Vtable
struct _jc_java_nio_channels_VMChannels$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_VMChannels$vmethods	java_nio_channels_VMChannels;
};

// Vtype
struct _jc_java_nio_channels_VMChannels$vtype {
	_jc_type			type;
	_jc_java_nio_channels_VMChannels$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_VMChannels$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_VMChannels$refs {
    _jc_java_nio_channels_VMChannels$sub_refs	java_nio_channels_VMChannels;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_VMChannels$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_VMChannels$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_VMChannels$sub_nonrefs	java_nio_channels_VMChannels;
};

// Object instance structure
struct _jc_java_nio_channels_VMChannels$object {
	_jc_java_nio_channels_VMChannels$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_VMChannels$vtype	*vtype;
	_jc_java_nio_channels_VMChannels$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_VMChannels$vtype _jc_java_nio_channels_VMChannels$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_VMChannels, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_VMChannels$class_object;

#endif	/* _JC_java_nio_channels_VMChannels_H_ */
